==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/mixin/HoneycombItemMixin.java <==
package com.zurrtum.create.mixin;

import com.google.common.collect.ImmutableBiMap;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.zurrtum.create.AllBlocks;
import net.minecraft.class_2248;
import net.minecraft.class_5953;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_5953.class)
public class HoneycombItemMixin {
    @WrapOperation(method = "method_34723", at = @At(value = "INVOKE", target = "Lcom/google/common/collect/ImmutableBiMap;builder()Lcom/google/common/collect/ImmutableBiMap$Builder;"), remap = false)
    private static ImmutableBiMap.Builder<class_2248, class_2248> addWaxed(Operation<ImmutableBiMap.Builder<class_2248, class_2248>> original) {
        ImmutableBiMap.Builder<class_2248, class_2248> builder = original.call();
        builder.put(AllBlocks.COPPER_SHINGLES, AllBlocks.WAXED_COPPER_SHINGLES);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLES, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLES);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLES, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLES);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLES, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLES);
        builder.put(AllBlocks.COPPER_SHINGLE_SLAB, AllBlocks.WAXED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.COPPER_TILES, AllBlocks.WAXED_COPPER_TILES);
        builder.put(AllBlocks.EXPOSED_COPPER_TILES, AllBlocks.WAXED_EXPOSED_COPPER_TILES);
        builder.put(AllBlocks.WEATHERED_COPPER_TILES, AllBlocks.WAXED_WEATHERED_COPPER_TILES);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILES, AllBlocks.WAXED_OXIDIZED_COPPER_TILES);
        builder.put(AllBlocks.COPPER_TILE_SLAB, AllBlocks.WAXED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.EXPOSED_COPPER_TILE_SLAB, AllBlocks.WAXED_EXPOSED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.WEATHERED_COPPER_TILE_SLAB, AllBlocks.WAXED_WEATHERED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILE_SLAB, AllBlocks.WAXED_OXIDIZED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.COPPER_TILE_STAIRS, AllBlocks.WAXED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.EXPOSED_COPPER_TILE_STAIRS, AllBlocks.WAXED_EXPOSED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.WEATHERED_COPPER_TILE_STAIRS, AllBlocks.WAXED_WEATHERED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILE_STAIRS, AllBlocks.WAXED_OXIDIZED_COPPER_TILE_STAIRS);
        return builder;
    }
}

==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/mixin/HoneycombItemMixin.java <==
package com.zurrtum.create.mixin;

import com.google.common.collect.ImmutableBiMap;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.zurrtum.create.AllBlocks;
import net.minecraft.class_2248;
import net.minecraft.class_5953;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_5953.class)
public class HoneycombItemMixin {
    @WrapOperation(method = "method_34723", at = @At(value = "INVOKE", target = "Lcom/google/common/collect/ImmutableBiMap;builder()Lcom/google/common/collect/ImmutableBiMap$Builder;", remap = false))
    private static ImmutableBiMap.Builder<class_2248, class_2248> addWaxed(Operation<ImmutableBiMap.Builder<class_2248, class_2248>> original) {
        ImmutableBiMap.Builder<class_2248, class_2248> builder = original.call();
        builder.put(AllBlocks.COPPER_SHINGLES, AllBlocks.WAXED_COPPER_SHINGLES);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLES, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLES);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLES, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLES);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLES, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLES);
        builder.put(AllBlocks.COPPER_SHINGLE_SLAB, AllBlocks.WAXED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLE_SLAB, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLE_SLAB);
        builder.put(AllBlocks.COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.EXPOSED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_EXPOSED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.WEATHERED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_WEATHERED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.OXIDIZED_COPPER_SHINGLE_STAIRS, AllBlocks.WAXED_OXIDIZED_COPPER_SHINGLE_STAIRS);
        builder.put(AllBlocks.COPPER_TILES, AllBlocks.WAXED_COPPER_TILES);
        builder.put(AllBlocks.EXPOSED_COPPER_TILES, AllBlocks.WAXED_EXPOSED_COPPER_TILES);
        builder.put(AllBlocks.WEATHERED_COPPER_TILES, AllBlocks.WAXED_WEATHERED_COPPER_TILES);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILES, AllBlocks.WAXED_OXIDIZED_COPPER_TILES);
        builder.put(AllBlocks.COPPER_TILE_SLAB, AllBlocks.WAXED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.EXPOSED_COPPER_TILE_SLAB, AllBlocks.WAXED_EXPOSED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.WEATHERED_COPPER_TILE_SLAB, AllBlocks.WAXED_WEATHERED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILE_SLAB, AllBlocks.WAXED_OXIDIZED_COPPER_TILE_SLAB);
        builder.put(AllBlocks.COPPER_TILE_STAIRS, AllBlocks.WAXED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.EXPOSED_COPPER_TILE_STAIRS, AllBlocks.WAXED_EXPOSED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.WEATHERED_COPPER_TILE_STAIRS, AllBlocks.WAXED_WEATHERED_COPPER_TILE_STAIRS);
        builder.put(AllBlocks.OXIDIZED_COPPER_TILE_STAIRS, AllBlocks.WAXED_OXIDIZED_COPPER_TILE_STAIRS);
        return builder;
    }
}
